@@ -29,6 +29,9 @@ FAILEDOPERATION_DATABASEACCESSERROR = 'FailedOperation.DatabaseAccessError'
 # 创建流程{{1}}失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_FLOWCREATEERROR = 'FailedOperation.FlowCreateError'
 
+# Flow不存在。
+FAILEDOPERATION_FLOWNOTFOUNDERROR = 'FailedOperation.FlowNotFoundError'
+
 # 获取备份策略失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_GETBACKUPSTRATEGYERROR = 'FailedOperation.GetBackupStrategyError'
 
@@ -38,6 +41,9 @@ FAILEDOPERATION_INSUFFICIENTBALANCE = 'FailedOperation.InsufficientBalance'
 # 操作失败{{1}}，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_OPERATIONFAILEDERROR = 'FailedOperation.OperationFailedError'
 
+# 规格信息{{1}}查询失败。
+FAILEDOPERATION_QUERYSPECBYSPECCODEERROR = 'FailedOperation.QuerySpecBySpecCodeError'
+
 # 创建并支付订单失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_TRADECREATEORDERERROR = 'FailedOperation.TradeCreateOrderError'
 
@@ -62,6 +68,9 @@ INTERNALERROR_INTERNALHTTPSERVERERROR = 'InternalError.InternalHttpServerError'
 # 安全组查询实例失败。
 INTERNALERROR_LISTINSTANCEFAILED = 'InternalError.ListInstanceFailed'
 
+# 操作外网失败。
+INTERNALERROR_OPERATEWANFAIL = 'InternalError.OperateWanFail'
+
 # 操作不支持。
 INTERNALERROR_OPERATIONNOTSUPPORT = 'InternalError.OperationNotSupport'
 
@@ -80,15 +89,33 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 当前实例不可隔离。
 INVALIDPARAMETER_ISOLATENOTALLOWED = 'InvalidParameter.IsolateNotAllowed'
 
+# 参数取值错误。
+INVALIDPARAMETERVALUE = 'InvalidParameterValue'
+
+# 账号已存在。
+INVALIDPARAMETERVALUE_ACCOUNTALREADYEXISTERROR = 'InvalidParameterValue.AccountAlreadyExistError'
+
+# 账号已存在。
+INVALIDPARAMETERVALUE_ACCOUNTEXIST = 'InvalidParameterValue.AccountExist'
+
+# 实例{{1}}不存在账号{{2}}。
+INVALIDPARAMETERVALUE_ACCOUNTNOTEXISTERROR = 'InvalidParameterValue.AccountNotExistError'
+
 # 未查询到集群。
 INVALIDPARAMETERVALUE_CLUSTERNOTFOUND = 'InvalidParameterValue.ClusterNotFound'
 
 # 不支持的实例类型。
 INVALIDPARAMETERVALUE_DBTYPENOTFOUND = 'InvalidParameterValue.DBTypeNotFound'
 
+# 集群类型必须为serverless。
+INVALIDPARAMETERVALUE_DBMODENOTSERVERLESSERROR = 'InvalidParameterValue.DbModeNotServerlessError'
+
 # 未查询到订单id。
 INVALIDPARAMETERVALUE_DEALNAMENOTFOUND = 'InvalidParameterValue.DealNameNotFound'
 
+# 任务流ID不存在。
+INVALIDPARAMETERVALUE_FLOWNOTFOUND = 'InvalidParameterValue.FlowNotFound'
+
 # 实例名称字符非法。
 INVALIDPARAMETERVALUE_ILLEGALINSTANCENAME = 'InvalidParameterValue.IllegalInstanceName'
 
@@ -101,6 +128,9 @@ INVALIDPARAMETERVALUE_ILLEGALPASSWORD = 'InvalidParameterValue.IllegalPassword'
 # 实例不存在。
 INVALIDPARAMETERVALUE_INSTANCENOTFOUND = 'InvalidParameterValue.InstanceNotFound'
 
+# 内置账号不允许操作。
+INVALIDPARAMETERVALUE_INTERNALACCOUNT = 'InvalidParameterValue.InternalAccount'
+
 # 实例版本非法。
 INVALIDPARAMETERVALUE_INVALIDDBVERSION = 'InvalidParameterValue.InvalidDBVersion'
 
@@ -122,6 +152,9 @@ INVALIDPARAMETERVALUE_PARAMBOTHSETERROR = 'InvalidParameterValue.ParamBothSetErr
 # 参数错误。
 INVALIDPARAMETERVALUE_PARAMERROR = 'InvalidParameterValue.ParamError'
 
+# 预付费类型不允许该操作。
+INVALIDPARAMETERVALUE_PREPAYPAYMODEERROR = 'InvalidParameterValue.PrePayPayModeError'
+
 # 所选地域和可用区不可用。
 INVALIDPARAMETERVALUE_REGIONZONEUNAVAILABLE = 'InvalidParameterValue.RegionZoneUnavailable'
 
@@ -143,6 +176,9 @@ OPERATIONDENIED_CLUSTEROPNOTALLOWEDERROR = 'OperationDenied.ClusterOpNotAllowedE
 # 集群{{1}}当前状态不允许该操作。
 OPERATIONDENIED_CLUSTERSTATUSDENIEDERROR = 'OperationDenied.ClusterStatusDeniedError'
 
+# 实例{{1}}当前状态不允许该操作。
+OPERATIONDENIED_INSTANCESTATUSDENIEDERROR = 'OperationDenied.InstanceStatusDeniedError'
+
 # 账号余额不足。
 OPERATIONDENIED_INSUFFICIENTBALANCEERROR = 'OperationDenied.InsufficientBalanceError'
 
@@ -155,12 +191,18 @@ OPERATIONDENIED_SERVERLESSINSTANCESTATUSDENIED = 'OperationDenied.ServerlessInst
 # 用户未进行实名认证，请先进行实名认证才可购买。
 OPERATIONDENIED_USERNOTAUTHENTICATEDERROR = 'OperationDenied.UserNotAuthenticatedError'
 
+# Serverless不支持该版本{{1}}。
+OPERATIONDENIED_VERSIONNOTSUPPORTERROR = 'OperationDenied.VersionNotSupportError'
+
 # 集群{{1}}不存在。
 RESOURCENOTFOUND_CLUSTERNOTFOUNDERROR = 'ResourceNotFound.ClusterNotFoundError'
 
 # 实例{{1}}不存在。
 RESOURCENOTFOUND_INSTANCENOTFOUNDERROR = 'ResourceNotFound.InstanceNotFoundError'
 
+# 参数{{1}}对应资源不存在。
+RESOURCENOTFOUND_RESOURCEERROR = 'ResourceNotFound.ResourceError'
+
 # 锁定实例失败，暂时不可操作。
 RESOURCEUNAVAILABLE_INSTANCELOCKFAIL = 'ResourceUnavailable.InstanceLockFail'
 
